	['arabic'] = {
		loader = 'hyph-ar.tex',
		lefthyphenmin = 0,
		righthyphenmin = 0,
		synonyms = {  },
	},
	['farsi'] = {
		loader = 'hyph-fa.tex',
		lefthyphenmin = 0,
		righthyphenmin = 0,
		synonyms = { 'persian' },
	},
